**EN 1993-5 - February 2007
Eurocode 3: Design of steel structures
Part 5: Piling**

The table presents a list of formulas from the Eurocode 3 standards for steel structures, part 5 Piling, tracking their implementation status
(:x: or :heavy_check_mark:) and any pertinent remarks. The 'Object Name' column references the corresponding Python entities inside of Blueprints.

Total of 63 formulas present.

Total of 63 formulas present.

| Formula number |        Done        | Remarks | Object name                                      |
|:---------------|:------------------:|:--------|:-------------------------------------------------|
| 5.1            |        :x:         |         |                                                  |
| 5.2            | :heavy_check_mark: |         | Form5Dot2DesignMomentResistanceClass1Or2         |
| 5.3            | :heavy_check_mark: |         | Form5Dot3DesignMomentResistanceClass3            |
| 5.4            |        :x:         |         |                                                  |
| 5.5            | :heavy_check_mark: |         | Form5Dot5PlasticShearResistance                  |
| 5.6            | :heavy_check_mark: |         | Form5Dot6ProjectedShearArea                      |
| 5.7            | :heavy_check_mark: |         | Form5Dot7ShearBucklingResistance                 |
| 5.8            | :heavy_check_mark: |         | Form5Dot8RelativeWebSlenderness                  |
| 5.9            | :heavy_check_mark: |         | Form5Dot9ReducedBendingMomentResistance          |
| 5.10           | :heavy_check_mark: |         | Form5Dot10ReductionFactorShearArea               |
| 5.11           |        :x:         |         |                                                  |
| 5.12           | :heavy_check_mark: |         | Form5Dot12ElasticCriticalLoad                    |
| 5.13           | :heavy_check_mark: |         | Form5Dot13SimplifiedBucklingCheck                |
| 5.14           |        :x:         |         |                                                  |
| 5.15           |        :x:         |         |                                                  |
| 5.16           | :heavy_check_mark: |         | Form5Dot16PlasticDesignResistance                |
| 5.17           | :heavy_check_mark: |         | Form5Dot17CompressionCheckZProfilesClass1And2    |
| 5.18           | :heavy_check_mark: |         | Form5Dot18CompressionCheckUProfilesClass1And2    |
| 5.19           | :heavy_check_mark: |         | Form5Dot19CompressionCheckClass3Profiles         |
| 5.20           | :heavy_check_mark: |         | Form5Dot20ReducedMomentResistanceClass2ZProfiles |
| 5.21           | :heavy_check_mark: |         | Form5Dot21ReducedMomentResistanceClass2UProfiles |
| 5.22           | :heavy_check_mark: |         | Form5Dot22ReducedMomentResistanceClass3          |
| 5.23           |        :x:         |         |                                                  |
| 5.24           |        :x:         |         |                                                  |
| 5.25           |        :x:         |         |                                                  |
| 5.26           |        :x:         |         |                                                  |
| 5.27           |        :x:         |         |                                                  |
| 5.28           |        :x:         |         |                                                  |
| 6.1            |        :x:         |         |                                                  |
| 7.1            |        :x:         |         |                                                  |
| 7.2            |        :x:         |         |                                                  |
| 7.3            |        :x:         |         |                                                  |
| 7.4            |        :x:         |         |                                                  |
| 7.5            |        :x:         |         |                                                  |
| 7.6            |        :x:         |         |                                                  |
| 7.7            |        :x:         |         |                                                  |
| 7.8            |        :x:         |         |                                                  |
| 7.9            |        :x:         |         |                                                  |
| 7.10           |        :x:         |         |                                                  |
| 7.11           |        :x:         |         |                                                  |
| 7.12           |        :x:         |         |                                                  |
| 7.13           |        :x:         |         |                                                  |
| 7.14           |        :x:         |         |                                                  |
| 7.15           |        :x:         |         |                                                  |
| 7.16           |        :x:         |         |                                                  |
| 7.17           |        :x:         |         |                                                  |
| A.1            |        :x:         |         |                                                  |
| A.2            |        :x:         |         |                                                  |
| A.3            |        :x:         |         |                                                  |
| A.4            |        :x:         |         |                                                  |
| A.5            |        :x:         |         |                                                  |
| B.1            |        :x:         |         |                                                  |
| C.1            |        :x:         |         |                                                  |
| C.2            |        :x:         |         |                                                  |
| C.3            |        :x:         |         |                                                  |
| C.4            |        :x:         |         |                                                  |
| C.5            |        :x:         |         |                                                  |
| C.6            |        :x:         |         |                                                  |
| D.1            |        :x:         |         |                                                  |
| D.2            |        :x:         |         |                                                  |
| D.3            |        :x:         |         |                                                  |
| D.4            |        :x:         |         |                                                  |
| D.5            |        :x:         |         |                                                  |
| D.6            |        :x:         |         |                                                  |